@@ -1,12 +1,12 @@
-#' Extract numeric case IDs by neighborhood.
+#'  Numeric case IDs by pump neighborhood.
 #'
 #' @param obj An object created by neighborhoodVoronoi() or neighborhoodWalking().
 #' @seealso \code{\link{neighborhoodVoronoi}}, \code{\link{neighborhoodWalking}},
-#' @return A list of pump neighborhoods with the numeric ID of observed cases.
+#' @return A list of pump neighborhoods with the numeric ID of cases.
 #' @export
 #' @examples
-#' pumpCase(neighborhoodVoronoi())
-#' pumpCase(neighborhoodWalking())
+#' # pumpCase(neighborhoodVoronoi())
+#' # pumpCase(neighborhoodWalking())
 
 pumpCase <- function(obj) UseMethod("pumpCase", obj)
 
@@ -40,11 +40,6 @@ pumpCase.walking <- function(obj) {
     stop('Input object\'s class needs to be "walking".')
   }
 
-  output <- obj$pump.case
-
-  if (obj$vestry == TRUE) {
-    stats::setNames(output, paste0("p", 1:14))
-  } else {
-    stats::setNames(output, paste0("p", 1:13))
-  }
+  output <- obj$cases
+  stats::setNames(output, paste0("p", names(output)))
 }
