@@ -16,30 +16,7 @@ simulateFatalities <- function(compute = FALSE, multi.core = FALSE,
     regular.cases <- cholera::regular.cases
     list(sim.ortho.proj = sim.ortho.proj, regular.cases = regular.cases)
   } else {
-    if (is.logical(multi.core)) {
-      if (multi.core == TRUE) {
-        cores <- parallel::detectCores()
-      } else {
-        if (is.numeric(multi.core)) {
-          if (is.integer(multi.core)) {
-            cores <- multi.core
-          } else {
-            cores <- as.integer(multi.core)
-          }
-        } else {
-          cores <- 1L
-        }
-      }
-    } else if (is.numeric(multi.core)) {
-      if (is.integer(multi.core)) {
-        cores <- multi.core
-      } else {
-        cores <- as.integer(multi.core)
-      }
-    }
-
-    ## road segment data ##
-
+    cores <- multiCore(multi.core)
     rd <- cholera::roads[cholera::roads$street %in% cholera::border == FALSE, ]
     map.frame <- cholera::roads[cholera::roads$street %in% cholera::border, ]
     roads.list <- split(rd[, c("x", "y")], rd$street)
